@@ -144,9 +144,9 @@ class ScrollArea(QAbstractScrollArea):
         else:
             viewport = self.viewport()
             vbar.setRange(0, h - viewport.height())
-            vbar.setPageStep(viewport.height() * .9)
+            vbar.setPageStep(int(viewport.height() * .9))
             hbar.setRange(0, w - viewport.width())
-            hbar.setPageStep(viewport.width() * .9)
+            hbar.setPageStep(int(viewport.width() * .9))
 
     def scrollOffset(self):
         """Return the current scroll offset."""
@@ -253,7 +253,7 @@ class ScrollArea(QAbstractScrollArea):
         """Begin a scrolling operation using the specified scroller."""
         self._scroller = scroller
         if self._scrollTimer is None:
-            self._scrollTimer = self.startTimer(1000 / self.scrollupdatespersec)
+            self._scrollTimer = self.startTimer(int(1000 // self.scrollupdatespersec))
 
     def stopScrolling(self):
         """Stop scrolling."""
@@ -323,9 +323,9 @@ class ScrollArea(QAbstractScrollArea):
                 speed = speed * 1000 / self.scrollupdatespersec / time
                 # compute diff to scroll
                 sx = abs(speed.x())
-                diffx = sx * (sx + 1) / 2
+                diffx = int(sx * (sx + 1) / 2)
                 sy = abs(speed.y())
-                diffy = sy * (sy + 1) / 2
+                diffy = int(sy * (sy + 1) / 2)
                 if speed.x() < 0: diffx = -diffx
                 if speed.y() < 0: diffy = -diffy
                 self.kineticScrollBy(QPoint(diffx, diffy))
@@ -438,8 +438,8 @@ class KineticScroller(Scroller):
         dy = diff.y()
 
         # solve speed*(speed+1)/2 = delta to ensure 1+2+3+...+speed is as close as possible under delta..
-        sx = (math.sqrt(1 + 8 * abs(dx)) - 1) // 2
-        sy = (math.sqrt(1 + 8 * abs(dy)) - 1) // 2
+        sx = int(math.sqrt(1 + 8 * abs(dx)) - 1) // 2
+        sy = int(math.sqrt(1 + 8 * abs(dy)) - 1) // 2
 
         # compute the amount of displacement still needed because we're dealing with integer values.
         # Since this function is called for exact moves (not free scrolling)
